@@ -4,7 +4,7 @@ import sys, os, re, inspect
 from pathlib import Path
 from textwrap import dedent
 from more_itertools import one, first
-from .layers import Layer, not_found
+from .layers import Layer, dict_like
 from ..utils import lookup, first_specified
 from ..errors import ConfigError
 
@@ -23,6 +23,60 @@ class CompositeConfig(Config):
             yield from config.load(obj)
 
 
+class SelfConfig(Config):
+    """
+    This config simply provides access to the object associated with the 
+    parameter in question.  By using callable keys, you can access any 
+    attribute on the object.  If the object also happens to implement 
+    `__getitem__()`, it will be used to lookup string keys.
+
+    Example:
+
+    >>> class MyApp:
+    ...     __config__ = [SelfConfig]
+    ...     
+    ...     x = appcli.param(
+    ...             Key(SelfConfig, lambda self: self._helper()),
+    ...     )
+    ...     
+    ...     def _helper(self):
+    ...         return 42
+    ...
+    >>> app = MyApp()
+    >>> app.x
+    42
+    """
+
+    def load(self, obj):
+        yield Layer(
+                values=obj,
+                location=_guess_module_path(obj),
+        )
+
+
+class AttrConfig(Config):
+    """
+    Read parameters from another attribute of the object.
+    """
+
+    def __init__(self, attr, f=lambda obj, x: x):
+        self.attr = attr
+        self.func = f
+
+    def load(self, obj):
+
+        @dict_like(AttributeError)
+        def getter(key):
+            x = getattr(obj, self.attr)
+            x = self.func(obj, x)
+            return lookup(x, key)
+
+        yield Layer(
+                values=getter,
+                location=_guess_module_path(obj),
+        )
+
+
 class CallbackConfig(Config):
 
     def __init__(self, callback, *raises, location=None):
@@ -36,7 +90,7 @@ class CallbackConfig(Config):
             location = location(obj)
 
         yield Layer(
-                values=not_found(*self.raises)(self.callback),
+                values=dict_like(*self.raises)(self.callback),
                 location=location
         )
 
@@ -54,29 +108,6 @@ class DefaultConfig(Config):
                 location=self.location,
         )
 
-class AttrConfig(Config):
-    """
-    Read parameters from another attribute of the object.
-    """
-
-    def __init__(self, attr, f=lambda obj, x: x):
-        self.attr = attr
-        self.func = f
-
-    def load(self, obj):
-
-        @not_found(AttributeError)
-        def getter(key):
-            x = getattr(obj, self.attr)
-            x = self.func(obj, x)
-            return lookup(x, key)
-
-        cls = obj.__class__
-        yield Layer(
-                values=getter,
-                location=f'{inspect.getmodule(cls).__name__}.{cls.__qualname__}.{self.attr}',
-        )
-
 
 class EnvironmentConfig(Config):
 
@@ -86,6 +117,7 @@ class EnvironmentConfig(Config):
                 location="environment",
         )
 
+
 class ArgparseConfig(Config):
     autoload = False
 
@@ -303,6 +335,7 @@ class TomlConfig(FileConfig):
         import toml
         return toml.load(path)
 
+
 class NtConfig(FileConfig):
     suffixes = '.nt',
 
@@ -310,3 +343,9 @@ class NtConfig(FileConfig):
         import nestedtext as nt
         return nt.load(path)
 
+
+def _guess_module_path(x):
+    try:
+        return inspect.getmodule(x).__file__
+    except Exception:
+        return '???'
